@@ -11,13 +11,11 @@
 
 from meutils.pipe import *
 
-DATA_HOME = Path('data')
-MODEL_HOME = Path('model')
+DATA_HOME = Path(get_module_path('data', __file__))
+MODEL_HOME = Path(get_module_path('model', __file__))
 
 
-def data_list(type='data'):
-    return Path(type).glob('*') | xlist
 
 
 if __name__ == '__main__':
-    print(data_list())
+    MODEL_HOME.rglob('*') | xjoin('\n') | xprint
